// ExtCmnt.java

import java.io.*;
import java.util.regex.*;

class ExtCmnt
{
   public static void main (String [] args)
   {
      if (args.length != 2)
      {
          System.err.println ("usage: java ExtCmnt infile outfile");
          return;
      }

      Pattern p;
      try
      {
         // The following pattern lets this extract multi-line comments that
         // appear on a single line (e.g., /* same line */) and single-line
         // comments (e.g., // some line). Furthermore, the comment may
         // appear anywhere on the line.

         p = Pattern.compile (".*/\\*.*\\*/|.*//.*$");
      }
      catch (PatternSyntaxException e)
      {
         System.err.println ("Regex syntax error: " + e.getMessage ());
         System.err.println ("Error description: " + e.getDescription ());
         System.err.println ("Error index: " + e.getIndex ());
         System.err.println ("Erroneous pattern: " + e.getPattern ());
         return;
      }

      BufferedReader br = null;
      BufferedWriter bw = null;

      try
      {
          FileReader fr = new FileReader (args [0]);
          br = new BufferedReader (fr);

          FileWriter fw = new FileWriter (args [1]);
          bw = new BufferedWriter (fw);

          Matcher m = p.matcher ("");
          String line;
          while ((line = br.readLine ()) != null)
          {
             m.reset (line);
             if (m.matches ()) /* entire line must match */
             {
                 bw.write (line);
                 bw.newLine ();
             }
          }
      }
      catch (IOException e)
      {
          System.err.println (e.getMessage ());
          return;
      }
      finally // Close file
      {
          try
          {
              if (br != null)
                  br.close ();

              if (bw != null)
                  bw.close ();
          }
          catch (IOException e)
          {
          }
      }
   }
}

